<?php
namespace Digiwallet\Packages\Transaction\Client\Request;

use BadMethodCallException;
use Digiwallet\Packages\Transaction\Client\InvoiceLine\InvoiceLineInterface as InvoiceLine;
use Digiwallet\Packages\Transaction\Client\Response\CreateTransactionInterface as CreateTransactionResponse;
use Digiwallet\Packages\Transaction\Client\Response\CreateTransactionInterface as CreateTransactionResponseInterface;
use DigiwalletGuzzleHttp\Exception\GuzzleException;
use Psr\Http\Message\RequestInterface;

/**
 * Interface TransactionRequest
 * @package Digiwallet\Packages\Transaction\Client\Request
 */
interface CreateTransactionInterface extends RequestInterface
{
    /**
     * in case of a transaction with variable amount also specify $maxAmount. This will exclude Afterpay.
     * in case of a transaction with fixed amount only specify $minAmount
     * Both $minAmount and $maxAmount should be in cents so for 1 euro you should enter 100
     * @param int $minAmount
     * @param int|null $maxAmount
     * @return CreateTransactionInterface
     */
    public function withAmount($minAmount, $maxAmount = null);

    /**
     * @param string $consumerEmail
     * @return CreateTransactionInterface
     */
    public function withConsumerEmail($consumerEmail);

    /**
     * @param string $consumerIp
     * @return CreateTransactionInterface
     */
    public function withConsumerIp($consumerIp);

    /**
     * @param string $currencyCode
     * @return CreateTransactionInterface
     */
    public function withCurrency($currencyCode);

    /**
     * @param string $description
     * @return CreateTransactionInterface
     */
    public function withDescription($description);

    /**
     * @param int $outletId
     * @return CreateTransactionInterface
     */
    public function withOutlet($outletId);

    /**
     * @param string $bearer
     * @return CreateTransactionInterface
     */
    public function withBearer($bearer);

    /**
     * @param string $header
     * @param string $value
     * @return CreateTransactionInterface
     */
    public function withHeaderValue($header, $value);

    /**
     * @param int $environment
     * @return CreateTransactionInterface
     */
    public function withEnvironment($environment);

    /**
     * @param string $preferredLanguage
     * @return CreateTransactionInterface
     */
    public function withLanguagePreference($preferredLanguage);

    /**
     * @param string $reportUrl
     * @return CreateTransactionInterface
     */
    public function withReportUrl($reportUrl);

    /**
     * @param string $cancelUrl
     * @return CreateTransactionInterface
     */
    public function withCancelUrl($cancelUrl);

    /**
     * @param string $tariffGroup
     * @return CreateTransactionInterface
     */
    public function withTariffGroup($tariffGroup);

    /**
     * @param string $returnUrl
     * @return CreateTransactionInterface
     */
    public function withReturnUrl($returnUrl);

    /**
     * @param string[]|iterable $paymentMethods
     * @return CreateTransactionInterface
     */
    public function withPaymentMethods($paymentMethods);

    /**
     * @return bool
     */
    public function validate();

    /**
     * @param int $productTypeId
     * @return CreateTransactionInterface
     */
    public function withProductType($productTypeId);

    /**
     * @param InvoiceLine[]|array $invoiceLines
     * @return CreateTransactionInterface
     */
    public function withInvoiceLines(array $invoiceLines);

    /**
     * @return CreateTransactionResponseInterface
     * @throws GuzzleException
     * @throws BadMethodCallException
     */
    public function send();
}
